package com.example.mascotaandroid;

import java.util.List;

import android.app.Activity;
import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.util.Log;
import android.widget.ImageView;
import android.widget.TextView;

public class JugarActivity extends Activity implements SensorEventListener{

//	private VistaJuego vistaJuego;
	
	//Senson manager
	SensorManager mSensorManager;
	
	//Valor anterior del sensor de aceleracin
	private boolean hayValorAnterior=false;
	private float valorAnterior;
	
	private TextView tMensaje;
	private ImageView iMascota;
	
	private boolean juegoActivo = true;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		Log.d("GGP","JugarActividad: onCreate");
		super.onCreate(savedInstanceState);
		setContentView(R.layout.jugar);
		
		//Cargamos las vistas
		tMensaje = (TextView) findViewById(R.id.textViewMensaje);
		iMascota = (ImageView) findViewById(R.id.imageViewMascota);
		
		//Registramos el sensor e indicamos que nuestro objeto recoger la llamada callback
		mSensorManager = (SensorManager) this.getSystemService(Context.SENSOR_SERVICE);
		
	}
	
	@Override protected void onPause() {
	       super.onPause();
	       Log.d("GGP","JugarActividad: onPause");
//	       vistaJuego.getThread().pausar();
	       this.desactivarSensores();
	}
	 
	@Override protected void onResume() {
	       super.onResume();
	       Log.d("GGP","JugarActividad: onResume");
	       this.activarSensores();
//	       vistaJuego.getThread().reanudar();
	}

	@Override
	public void onSensorChanged(SensorEvent event) {
		if(juegoActivo){
			Log.d("GGP","JugarActividad: onSensonChanged");
			float valor = event.values[1];
			if (!hayValorAnterior) {
				hayValorAnterior = true;
				valorAnterior = valor;
			}
			Log.d("GGP", "SENSOR: valor=" + valor + " valorAnterior="+ valorAnterior);
			
			//Si hay movimiento en el telefono se entiende que la mascota se divierte
			if(valor!=valorAnterior){
				aumentarFelicidad(valor);
				iMascota.setImageDrawable(this.getResources().getDrawable(R.drawable.mascota_contento));
			} else{
				iMascota.setImageDrawable(this.getResources().getDrawable(R.drawable.mascota_normal));
			}
			
			valorAnterior = valor;
		} else {
			Log.d("GGP","Juego no activo");
		}

	}

	@Override
	public void onAccuracyChanged(Sensor sensor, int accuracy) {
		// TODO Auto-generated method stub
	}
	
	/**
	 * Cuando ms se mueva la mascota, ms se divierte y aumenta su felicidad
	 */
	private void aumentarFelicidad(float valor){
		int valorAumentoFelicidad =0;
		
		int valorDiferencia = (int) (valor-valorAnterior);
		if (valorDiferencia<0) valorDiferencia=valorDiferencia*-1;
		if(valorDiferencia<=50){
			valorAumentoFelicidad = 1;
			int felicidadValor = LogicaNegocio.jugar(valorAumentoFelicidad);
			Log.d("GGP","Felicidad actual: "+felicidadValor);
			
//			tMensaje.setText("Felicidad: "+felicidadValor);
			tMensaje.setText("Felicidad aumentando! sigue girando! ");
			
			//Si la felicidad ha llegado al 100 paramos el juego
			if(felicidadValor == 100) {
				pararJuego();
			}
		}
	}
	
	private void pararJuego(){
		juegoActivo = false;
		iMascota.setImageDrawable(this.getResources().getDrawable(R.drawable.mascota_muy_contento));
		tMensaje.setText("Conseguido! tu mascota est contenta!");
		this.desactivarSensores();
	}
	
	/**
	 * Activa los sensores de la aplicacion
	 */
	private void activarSensores(){
		Log.d("GGP","JugarActividad: activarSensores");
		//Registramos el sensor e indicamos que nuestro objeto recoger la llamada callback
		List<Sensor> listSensors = mSensorManager.getSensorList(Sensor.TYPE_ORIENTATION);
		if (!listSensors.isEmpty()) {
			Sensor accelerometerSensor = listSensors.get(0);
			mSensorManager.registerListener(this, accelerometerSensor,SensorManager.SENSOR_DELAY_GAME);
			Log.d("GGP","SENSORES ACTIVADOS");
		}
	}
	
	/**
	 * Desactiva los sensores de la aplicacin
	 * Importande usar este mtodo cuando sea adecuado para el consumo de batera
	 */
	private void desactivarSensores(){
		Log.d("GGP","JugarActividad: desactivarSensores");
		mSensorManager.unregisterListener(this);
		Log.d("GGP","SENSORES DESACTIVADOS");
	}
}
