package com.example.mascotaandroid;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.util.Log;

public class LogicaNegocio {
	private static MascotaDAO mascotaDAO;
	private static Mascota mascota;
	
	public static int PORCENTAJE_ALERTA_ALIMENTACION = 10;
	public static int PORCENTAJE_ALERTA_DESCANSO = 10;
	public static int PORCENTAJE_ALERTA_FELICIDAD = 10;
	public static int PORCENTAJE_ALIMENTACION_BUENO = 50;
	public static int PORCENTAJE_DESCANSO_BUENO = 50;
	public static int PORCENTAJE_FELICIDAD_BUENO = 50;
	public static int PORCENTAJE_ALIMENTACION_MUY_BUENO = 80;
	public static int PORCENTAJE_DESCANSO_MUY_BUENO = 80;
	public static int PORCENTAJE_FELICIDAD_MUY_BUENO = 80;
	
	
	private static NotificationManager notificationManager;
	private static final int ID_NOTIFICACION_ALERTA_ALIMENTACION = 1;
	private static final int ID_NOTIFICACION_ALERTA_DESCANSO = 2;
	private static final int ID_NOTIFICACION_ALERTA_FELICIDAD = 3;
	
	private static final int AUMENTO_ALIMENTAR=10;
	private static final int AUMENTO_DORMIR=10;
//	private static final int AUMENTO_JUGAR=10;
	
//	private static Notification notificationAlimentacion;
//	private static Notification notificationDescanso;
//	private static Notification notificationFelicidad; 
	
	public static void inicializaBD(Context contexto){
		//Inicializamos la base de datos
		mascotaDAO = new MascotaDAOSQLite(contexto);
		
		//Inicializamos el notificationManager
		notificationManager = (NotificationManager)contexto.getSystemService(Context.NOTIFICATION_SERVICE);
		
	}
	
	public static Mascota getEstadoMascota(){
//		Log.d("GGP","LogicaNegocio: getEstadoMascota");
		return mascotaDAO.getEstadoMascota();
	}
	
	//Cada vez que ha pasado un determinado intervalo de tiempo, el estado de la mascota cambia
	public static Mascota haPasadoIntervaloDeTiempo(Context context){
		Log.d("GGP","LogicaNegocio: haPasadoIntervaloDeTiempo");
		//Recuperamos el estado actual de la mascota
		mascota = mascotaDAO.getEstadoMascota();
		//variamos el estado por el paso del tiempo (los porcentajes de alimentacin, descanso y felicidad se reducirn)
		mascota.reducirEstados();
		//Comprobamos si hay que lanzar notificaciones por estados con bajo porcentaje
		lanzarNotificacionesEstado(mascota,context);
		
		actualizarEstado(mascota);
		
		return mascota;
	}
	
	/**
	 * Comprobamos si hay que lanzar notificaciones por estados con bajo porcentaje
	 */
	private static void lanzarNotificacionesEstado(Mascota mascota, Context context){
		SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(context);
		//Comprobamos si las notificaciones estan activadas en las preferencias
		if(pref.getBoolean("notificaciones", true)) {
			if(mascota.getAlimentacion()<PORCENTAJE_ALERTA_ALIMENTACION){
				Notification notificationAlimentacion = new Notification(R.drawable.ic_notificacion,"Tengo hambre!",System.currentTimeMillis());
				PendingIntent intencionPendiente = PendingIntent.getActivity(context, 0, new Intent(context, MascotaActivity.class), 0);
				notificationAlimentacion.setLatestEventInfo(context, "\"Tengo hambre!\"", "Dale de comer a tu mascota", intencionPendiente);
				notificationAlimentacion.defaults = Notification.DEFAULT_VIBRATE;
				notificationManager.notify(ID_NOTIFICACION_ALERTA_ALIMENTACION,notificationAlimentacion);
			} else {
				notificationManager.cancel(ID_NOTIFICACION_ALERTA_ALIMENTACION);
			}
			if(mascota.getDescanso()<PORCENTAJE_ALERTA_DESCANSO){
				Notification notificationDescanso = new Notification(R.drawable.ic_notificacion,"Tengo sueo!",System.currentTimeMillis());
				PendingIntent intencionPendiente = PendingIntent.getActivity(context, 0, new Intent(context, MascotaActivity.class), 0);
				notificationDescanso.setLatestEventInfo(context, "\"Tengo sueo!\"", "Pon tu mascota a descansar", intencionPendiente);
				notificationDescanso.defaults = Notification.DEFAULT_VIBRATE;
				notificationManager.notify(ID_NOTIFICACION_ALERTA_DESCANSO,notificationDescanso);
			} else {
				notificationManager.cancel(ID_NOTIFICACION_ALERTA_DESCANSO);
			}
			if(mascota.getFelicidad()<PORCENTAJE_ALERTA_FELICIDAD){
				Notification notificationFelicidad = new Notification(R.drawable.ic_notificacion,"Me aburro!",System.currentTimeMillis());
				PendingIntent intencionPendiente = PendingIntent.getActivity(context, 0, new Intent(context, MascotaActivity.class), 0);
				notificationFelicidad.setLatestEventInfo(context, "\"Me aburro!\"", "Juega con tu mascota", intencionPendiente);
				notificationFelicidad.defaults = Notification.DEFAULT_VIBRATE;
				notificationManager.notify(ID_NOTIFICACION_ALERTA_FELICIDAD,notificationFelicidad);
			} else {
				notificationManager.cancel(ID_NOTIFICACION_ALERTA_FELICIDAD);
			}
			
		}
	}
	
	public static void alimentar(){
		//Recuperamos el estado actual de la mascota
		mascota = mascotaDAO.getEstadoMascota();
		mascota.setAlimentacion(mascota.getAlimentacion()+AUMENTO_ALIMENTAR);
		actualizarEstado(mascota);
	}
	
	public static void dormir(){
		//Recuperamos el estado actual de la mascota
		mascota = mascotaDAO.getEstadoMascota();
		mascota.setDescanso(mascota.getAlimentacion()+AUMENTO_DORMIR);
		actualizarEstado(mascota);
	}
	
	public static int jugar(int valorAumentar){
		mascota = mascotaDAO.getEstadoMascota();
		Log.d("GGP","    felicidad antes de cambiar: "+mascota.getFelicidad());
		if(valorAumentar>0){
			Log.d("GGP","       aumentamos en +"+valorAumentar);
			mascota.setFelicidad(mascota.getFelicidad()+valorAumentar);
		}
		actualizarEstado(mascota);
		Log.d("GGP","    felicidad antes de cambiar: "+mascota.getFelicidad());
		
		return mascota.getFelicidad();
	}
	
	private static void actualizarEstado(Mascota mascota){
		mascotaDAO.actualizarPorcentajes(mascota);
	}
}


