package com.example.mascotaandroid;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.SystemClock;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

public class MascotaActivity extends Activity{

	private TextView datoAlimentacion;
	private TextView datoDescanso;
	private TextView datoFelicidad;
	
	private Button bAlimentar;
	private Button bDormir;
	private Button bJugar;
	
	private ImageView iMascota;
	
	private Mascota mascota;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		Log.d("GGP","Mascota: onCreate");
		super.onCreate(savedInstanceState);
		setContentView(R.layout.mascota);
		
		iMascota = (ImageView) findViewById(R.id.imageViewMascotaEstado);
		
		//Recuperamos los datos del estado de la mascota
		Log.d("GGP","Mascota: antes de inicializar mascota");
		mascota = LogicaNegocio.getEstadoMascota();
		Log.d("GGP","Mascota: despues de inicializar mascota");
		
		//Mostramos los porcentajes en pantalla
		datoAlimentacion = (TextView) findViewById(R.id.textViewDatoAlimentacion);
		datoDescanso = (TextView) findViewById(R.id.textViewDatoDescanso);
		datoFelicidad = (TextView) findViewById(R.id.textViewDatoFelicidad);
		datoAlimentacion.setText(Integer.toString(mascota.getAlimentacion()));
		datoDescanso.setText(Integer.toString(mascota.getDescanso()));
		datoFelicidad.setText(Integer.toString(mascota.getFelicidad()));
		
		//Botones
		bAlimentar = (Button) findViewById(R.id.buttonAlimentar);
		bDormir = (Button) findViewById(R.id.buttonDormir);
		bJugar = (Button) findViewById(R.id.buttonJugar);
		
		bAlimentar.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				alimentar();
			}
		});

		bDormir.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				dormir();
			}
		});
		
		bJugar.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				jugar();
			}
		});
		
		//Receptor de anuncio para actualizar los estados cuando lo haga el servicio
		IntentFilter filtro = new IntentFilter(ReceptorActualizacionEstado.ACTION_RESP);
		filtro.addCategory(Intent.CATEGORY_DEFAULT);
		registerReceiver(new ReceptorActualizacionEstado(), filtro);
	}
	
	private void alimentar(){
		LogicaNegocio.alimentar();
		mascota = LogicaNegocio.getEstadoMascota();
		datoAlimentacion.setText(Integer.toString(mascota.getAlimentacion()));
//		Toast.makeText(this, "Qu rico!", Toast.LENGTH_SHORT).show();

	}
	
	private void dormir(){
		LogicaNegocio.dormir();
		mascota = LogicaNegocio.getEstadoMascota();
		datoDescanso.setText(Integer.toString(mascota.getDescanso()));
//		Toast.makeText(this, "Buenas noches!", Toast.LENGTH_SHORT).show();
	}
	
	private void jugar(){
//		LogicaNegocio.jugar();
//		mascota = LogicaNegocio.getEstadoMascota();
//		datoFelicidad.setText(Integer.toString(mascota.getFelicidad()));
//		Toast.makeText(this, "Gracias!", Toast.LENGTH_SHORT).show();
		Intent i = new Intent(this,JugarActivity.class);
//		Log.d("GGP","MascotaActivity: jugar - antes de startActivity");
		startActivity(i);
	}
	
	public class ReceptorActualizacionEstado extends BroadcastReceiver{

		public static final String ACTION_RESP = "com.example.mascotaandroid.intent.action.RESPUESTA_ACTUALIZACION_ESTADO";
		
		@Override
		public void onReceive(Context context, Intent intent) {
//			Log.d("GGP","ReceptorActualizacionEstado");
			int[] estado = intent.getIntArrayExtra("estado");
			datoAlimentacion.setText(Integer.toString(estado[0]));
			datoDescanso.setText(Integer.toString(estado[1]));
			datoFelicidad.setText(Integer.toString(estado[2]));
			actualizarImagen(context);
		}
		
		//Actualizamos la imagen de la mascota en funcin de su estado
		private void actualizarImagen(Context context){
			
			int valorAlimentacion = Integer.parseInt(datoAlimentacion.getText().toString());
			int valorDescanso = Integer.parseInt(datoDescanso.getText().toString());
			int valorFelicidad = Integer.parseInt(datoFelicidad.getText().toString());
			
			//Si tiene sueo
			if(valorDescanso < LogicaNegocio.PORCENTAJE_ALERTA_DESCANSO){
				Log.d("GGP","Dibujo1");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_durmiendo));
			}
			//Si tiene hambre
			else if(valorAlimentacion < LogicaNegocio.PORCENTAJE_ALERTA_ALIMENTACION){
				Log.d("GGP","Dibujo2");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_regular));
			}
			//Si est aburrida
			else if(valorFelicidad < LogicaNegocio.PORCENTAJE_ALERTA_FELICIDAD){
				Log.d("GGP","Dibujo3");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_regular));
			}
			//Si est muy bien de todo
			else if(valorAlimentacion >= LogicaNegocio.PORCENTAJE_ALIMENTACION_MUY_BUENO && 
					valorDescanso >= LogicaNegocio.PORCENTAJE_DESCANSO_MUY_BUENO &&
					valorFelicidad >= LogicaNegocio.PORCENTAJE_FELICIDAD_MUY_BUENO){
				Log.d("GGP","Dibujo4");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_muy_contento));
			}
			//Si est bien de todo
			else if(valorAlimentacion >= LogicaNegocio.PORCENTAJE_ALIMENTACION_BUENO && 
					valorDescanso >= LogicaNegocio.PORCENTAJE_DESCANSO_BUENO &&
					valorFelicidad >= LogicaNegocio.PORCENTAJE_FELICIDAD_BUENO){
				Log.d("GGP","Dibujo4");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_contento));
			}
			else{
				Log.d("GGP","Dibujo5");
				iMascota.setImageDrawable(context.getResources().getDrawable(R.drawable.mascota_normal));
			}
			
		}
		
	}
}
